@@ -23,7 +23,7 @@ discopy computes natural language meaning in pictures.
 >>> assert A(sentence).normal_form() == Alice @ Bob >> love_box
 """
 
-from discopy import cat, monoidal, rigid, tensor, quantum, grammar
+from discopy import cat, monoidal, rigid, tensor, quantum, grammar, biclosed
 from discopy.cat import Quiver
 from discopy.rigid import (
     Ob, Ty, PRO, Box, Diagram, Id, Cup, Cap, Swap, Functor)
@@ -33,5 +33,6 @@ from discopy.quantum import (
     Discard, MixedState, Measure, Encode, Ket, Bra, Rx, Rz, CRz,
     SWAP, CZ, CX, H, S, T, X, Y, Z)
 from discopy.grammar import Word
+from discopy.biclosed import Over, Under
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
