@@ -72,21 +72,22 @@ class Ty(monoidal.Ty, Ob):
     >>> assert (s @ n).l == n.l @ s.l and (s @ n).r == n.r @ s.r
     """
     @staticmethod
-    def _upgrade(ty):
+    def upgrade(ty):
         return Ty(*ty.objects)
 
     @property
     def l(self):
-        """ Left adjoint. """
         return Ty(*[x.l for x in self.objects[::-1]])
 
     @property
     def r(self):
-        """ Right adjoint. """
         return Ty(*[x.r for x in self.objects[::-1]])
 
-    def tensor(self, *others):
-        return self._upgrade(super().tensor(*others))
+    @property
+    def z(self):
+        if len(self) != 1:
+            raise TypeError(messages.no_winding_number_for_complex_types())
+        return self[0].z
 
     def __init__(self, *t):
         t = [x if isinstance(x, Ob)
@@ -95,20 +96,25 @@ class Ty(monoidal.Ty, Ob):
         monoidal.Ty.__init__(self, *t)
         Ob.__init__(self, str(self))
 
-    def __getitem__(self, key):
-        if isinstance(key, slice):
-            return self._upgrade(super().__getitem__(key))
-        return super().__getitem__(key)
-
     def __repr__(self):
         return "Ty({})".format(', '.join(
             repr(x if x.z else x.name) for x in self.objects))
 
+    def __lshift__(self, other):
+        return self @ other.l
+
+    def __rshift__(self, other):
+        return self.r @ other
+
 
 class PRO(monoidal.PRO, Ty):
     """
     Objects of the free rigid monoidal category generated by 1.
     """
+    @staticmethod
+    def upgrade(ty):
+        return PRO(len(monoidal.PRO.upgrade(ty)))
+
     @property
     def l(self):
         """
@@ -131,7 +137,7 @@ class Diagram(monoidal.Diagram):
     Alice >> Id(n) @ jokes >> Cup(n, n.r) @ Id(s)
     """
     @staticmethod
-    def _upgrade(diagram):
+    def upgrade(diagram):
         """
         Takes a monoidal.Diagram and returns a rigid.Diagram.
         """
@@ -142,12 +148,6 @@ class Diagram(monoidal.Diagram):
     def id(x):
         return Id(x)
 
-    def then(self, *others):
-        return self._upgrade(super().then(*others))
-
-    def tensor(self, *others):
-        return self._upgrade(super().tensor(*others))
-
     @staticmethod
     def swap(left, right):
         return monoidal.swap(
@@ -159,17 +159,6 @@ class Diagram(monoidal.Diagram):
             dom = PRO(len(perm))
         return monoidal.permutation(perm, dom, ar_factory=Diagram)
 
-    def interchange(self, i, j, left=False):
-        return self._upgrade(super().interchange(i, j, left=left))
-
-    def flatten(self):
-        """
-        >>> x = Ty('x')
-        >>> f = Box('f', x, x)
-        >>> assert isinstance((f >> f >> f).foliation().flatten(), Diagram)
-        """
-        return self._upgrade(super().flatten())
-
     def foliate(self, yield_slices=False):
         """
         >>> x = Ty('x')
@@ -180,29 +169,9 @@ class Diagram(monoidal.Diagram):
         """
         for diagram in super().foliate(yield_slices=yield_slices):
             if isinstance(diagram, cat.Arrow):
-                yield self._upgrade(diagram)
+                yield self.upgrade(diagram)
             else:
-                yield [self._upgrade(diagram[i]) for i in range(len(diagram))]
-
-    def foliation(self):
-        """
-        >>> x = Ty('x')
-        >>> f = Box('f', x, x)
-        >>> assert isinstance((f @ Id(x) >> (f @ f)).foliation(), Diagram)
-        """
-        return self._upgrade(super().foliation())
-
-    def __getitem__(self, key):
-        """
-        >>> n, s = Ty('n'), Ty('s')
-        >>> cup, cap = Cup(n, n.r), Cap(n.r, n)
-        >>> f, g, h = Box('f', n, n), Box('g', s @ n, n), Box('h', n, n @ s)
-        >>> diagram = g @ cap >> f[::-1] @ Id(n.r) @ f >> cup @ h
-        >>> assert isinstance(diagram[1:3], Diagram)
-        >>> assert diagram[3:] == Id(n @ n.r) @ f >> cup @ h
-        >>> assert diagram[:2] >> diagram[2:] == diagram
-        """
-        return self._upgrade(super().__getitem__(key))
+                yield [self.upgrade(diagram[i]) for i in range(len(diagram))]
 
     @staticmethod
     def cups(left, right):
@@ -226,6 +195,20 @@ class Diagram(monoidal.Diagram):
         """
         return caps(left, right)
 
+    @staticmethod
+    def fa(left, right):
+        """ Forward application. """
+        off = -len(right) or len(left)
+        return Id(left[:off]) @ Diagram.cups(left[off:], right)
+
+
+    @staticmethod
+    def ba(left, right):
+        """ Backward application. """
+        off = -len(left) or len(right)
+        return Diagram.cups(left, right[:off]) @ Id(right[off:])
+
+
     def transpose(self, left=False):
         """
         >>> a, b = Ty('a'), Ty('b')
@@ -486,7 +469,7 @@ class Functor(monoidal.Functor):
         super().__init__(ob, ar, ob_factory=ob_factory, ar_factory=ar_factory)
 
     def __call__(self, diagram):
-        if isinstance(diagram, Ty):
+        if isinstance(diagram, monoidal.Ty):
             return sum([self(b) for b in diagram.objects], self.ob_factory())
         if isinstance(diagram, Ob) and not diagram.z:
             return self.ob[Ty(diagram.name)]
@@ -505,7 +488,7 @@ class Functor(monoidal.Functor):
         if isinstance(diagram, Cap):
             return self.ar_factory.caps(
                 self(diagram.cod[0]), self(diagram.cod[1]))
-        if isinstance(diagram, Diagram):
+        if isinstance(diagram, monoidal.Diagram):
             return super().__call__(diagram)
         raise TypeError(messages.type_err(Diagram, diagram))
 
